@@ -2,4 +2,4 @@
 
 # GNOME Tweaks no longer provides an on/off switch
 # for the lid inhibitor
-rm .config/autostart/ignore-lid-switch-tweak.desktop
+rm -f .config/autostart/ignore-lid-switch-tweak.desktop
